@extends('app')

@section('content')
<div class="section">
    <h2 class="fs-24 tss-m-sbold">Audio File for Registering Voice</h2>
    <div class="row">
        <div class="col-lg-8">
            <div class="boxed p-4 bg-white h-100">
                <div class="row align-items-center">
                    <div class="col-lg-6">
                        <div class="w-100 tss-attachment text-center">
                            <input type="file" class="tss-custom-file-input w-100 fUpload" id="fUpload" accept=".mp3,.wav,.ogg,.mpeg,.aac" name="file">
                            <div class="icon">
                                <i class="fa fa-paperclip" aria-hidden="true"></i>
                                <span class="tss-m-bold fs-14">Upload</span>
                            </div>
                            <p class="fs-12 text-gray mb-0 py-2">Upload Audio file</p>
                        </div>
                        <div class="note text-center fs-12 py-2"><span class="text-gray">*Max 50MB file should be uploaded</span></div>
                    </div>
                    <div class="col-lg-6">
                        <div class="progress mb-4" style="height: 0.5rem;">
                          <div class="progress-bar" id="upload_progress_bar" role="progressbar" style="width:0%" aria-valuenow="100" aria-valuemin="0" aria-valuemax="100"></div>
                        </div>
                        
                        <p class="fs-18 mb-1">Uploaded file:</p>
                        <p class="fs-18 tss-m-bold" id="filename"></p>
                        <p class="fs-16 text-gray tss-m-sbold"><span id="fileformat"></span> file</p>
                    </div>
                </div>

                <div id="uploadfileStatusMessage" class=""></div>
            </div>
        </div>
        <div class="col-lg-4">
            <div class="boxed p-4 bg-white h-100">
                <form id="splitAudio" method="POST" accept="javascript:0;">
                    @csrf
                    <input type="hidden" name="sample_rate" value="16" />
                    <div class="mb-3">
                        <label for="exampleFormControlInput1" class="form-label">Number of Speaker</label>
                        <select class="form-select" name="n_speaker" aria-label="Default select example" required>
                            <option value="0" disabled>Select Number of Speaker</option>
                            <option value="1">1</option>
                            <option value="2" selected>2</option>
                            <option value="3">3</option>
                            <option value="4">4</option>
                            <option value="5">5</option>
                        </select>
                    </div>
                    <div class="">
                        <div class="d-grid gap-2">
                            <button class="btn tss-btn-primary icon-btn px-4 py-lg-3" id="GetSplittedAudioBtn" disabled type="submit">
                                <span class="fs-18 tss-m-bold" id="GetSplittedAudioBtnSpan">Get Splitted Audio</span>
                                <i class="fa fa-arrow-right" aria-hidden="true"></i>    
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<div id="resultsMatchingDetailsDiv"></div>

@endsection
@section('script')
<script type="text/javascript">
    $(document).ready(function(){
        // alert("+++++++++++");
        $(document).on('change','#fUpload',function(){
            var property = document.getElementById('fUpload').files[0];
            var image_name = property.name;
            var image_extension = image_name.split('.').pop().toLowerCase();
            var percentage = '0';
            if(jQuery.inArray(image_extension,['mp3','wav','org','wav','mpeg','aac']) == -1){
                alert("Invalid audio file!");
                return;
            }

            setTimeout(function(){
                $('#upload_progress_bar').css("width", '30%', function() {
                    return $(this).attr("aria-valuenow", 30) + "%";
                });
            }, 3000);

            var form_data = new FormData();
            form_data.append("file", property);
            form_data.append("_token", '{{csrf_token()}}');
            $.ajaxSetup({
                header:$('meta[name="_token"]').attr('content')
            })
            $("#GetSplittedAudioBtn").attr('disabled','disabled');
            $(".loaderContainer").show();
            // console.log(form_data);
            $("#uploadfileStatusMessage").removeClass('alert_message');
            $("#uploadfileStatusMessage").text('');

            $.ajax({
                url: "{{route('split.audio.save.file')}}",
                method:'POST',
                data:form_data,
                contentType:false,
                cache:false,
                processData:false,
                beforeSend:function(){
                    setTimeout(function(){ 
                        $('#upload_progress_bar').css("width", '75%', function() {
                            return $(this).attr("aria-valuenow", 75) + "%";
                        });
                    }, 6000);
                },
                success:function(data){
                    console.log(data);
                    if(data.success == 1){
                        // console.log(data);
                        $(".loaderContainer").hide();
                        $("#GetSplittedAudioBtn").removeAttr('disabled');
                        $("#uploadfileStatusMessage").text(data.message).addClass('alert_message');
                        setInterval(() => {
                            $("#uploadfileStatusMessage").removeClass('alert_message');
                            $("#uploadfileStatusMessage").text('');
                        }, 3000);
                    }
                    $('#upload_progress_bar').css("width", '100%', function() {
                        return $(this).attr("aria-valuenow", 100) + "%";
                    });
                    return;
                }
            });
        });

        $("#splitAudio").submit(function(e){
            e.preventDefault();
            let data = $(this).serialize();
            $('#resultsMatchingDetailsDiv').html('');
            $(".loaderContainer").show();
            $.ajax({
                url: "{{route('split.audio.save.file.data')}}",
                method:'POST',
                data: data,
                beforeSend:function(){
                    $('#GetSplittedAudioBtnSpan').html('Please wait...');
                    $("#GetSplittedAudioBtn").attr('disabled','disabled');
                },
                success:function(data){
                    // console.log(data);
                    $(".loaderContainer").hide();
                    $("#GetSplittedAudioBtn").removeAttr('disabled');
                    $('#GetSplittedAudioBtnSpan').text('Get Splitted Audio');
                    $('#resultsMatchingDetailsDiv').html(data);
                }
            });
        });
    });
  </script>
@endsection